# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class WrapUpCodeMappingNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WrapUpCodeMappingNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flag': 'str',
            'default_set': 'list[str]',
            'mapping': 'dict(str, list[str])',
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'flag': 'flag',
            'default_set': 'defaultSet',
            'mapping': 'mapping',
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'additional_properties': 'additionalProperties'
        }

        self._flag = None
        self._default_set = None
        self._mapping = None
        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._additional_properties = None

    @property
    def flag(self):
        """
        Gets the flag of this WrapUpCodeMappingNotification.


        :return: The flag of this WrapUpCodeMappingNotification.
        :rtype: str
        """
        return self._flag

    @flag.setter
    def flag(self, flag):
        """
        Sets the flag of this WrapUpCodeMappingNotification.


        :param flag: The flag of this WrapUpCodeMappingNotification.
        :type: str
        """
        allowed_values = ["Contact_UnCallable", "Number_UnCallable", "Right_Party_Contact"]
        if flag.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for flag -> " + flag
            self._flag = "outdated_sdk_version"
        else:
            self._flag = flag.lower()

    @property
    def default_set(self):
        """
        Gets the default_set of this WrapUpCodeMappingNotification.


        :return: The default_set of this WrapUpCodeMappingNotification.
        :rtype: list[str]
        """
        return self._default_set

    @default_set.setter
    def default_set(self, default_set):
        """
        Sets the default_set of this WrapUpCodeMappingNotification.


        :param default_set: The default_set of this WrapUpCodeMappingNotification.
        :type: list[str]
        """
        
        self._default_set = default_set

    @property
    def mapping(self):
        """
        Gets the mapping of this WrapUpCodeMappingNotification.


        :return: The mapping of this WrapUpCodeMappingNotification.
        :rtype: dict(str, list[str])
        """
        return self._mapping

    @mapping.setter
    def mapping(self, mapping):
        """
        Sets the mapping of this WrapUpCodeMappingNotification.


        :param mapping: The mapping of this WrapUpCodeMappingNotification.
        :type: dict(str, list[str])
        """
        
        self._mapping = mapping

    @property
    def id(self):
        """
        Gets the id of this WrapUpCodeMappingNotification.


        :return: The id of this WrapUpCodeMappingNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WrapUpCodeMappingNotification.


        :param id: The id of this WrapUpCodeMappingNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WrapUpCodeMappingNotification.


        :return: The name of this WrapUpCodeMappingNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WrapUpCodeMappingNotification.


        :param name: The name of this WrapUpCodeMappingNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this WrapUpCodeMappingNotification.


        :return: The date_created of this WrapUpCodeMappingNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this WrapUpCodeMappingNotification.


        :param date_created: The date_created of this WrapUpCodeMappingNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this WrapUpCodeMappingNotification.


        :return: The date_modified of this WrapUpCodeMappingNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this WrapUpCodeMappingNotification.


        :param date_modified: The date_modified of this WrapUpCodeMappingNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this WrapUpCodeMappingNotification.


        :return: The version of this WrapUpCodeMappingNotification.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this WrapUpCodeMappingNotification.


        :param version: The version of this WrapUpCodeMappingNotification.
        :type: int
        """
        
        self._version = version

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this WrapUpCodeMappingNotification.


        :return: The additional_properties of this WrapUpCodeMappingNotification.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this WrapUpCodeMappingNotification.


        :param additional_properties: The additional_properties of this WrapUpCodeMappingNotification.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CampaignRuleNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignRuleNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'additional_properties': 'object',
            'campaign_rule_entities': 'CampaignRuleNotificationCampaignRuleEntities',
            'campaign_rule_conditions': 'list[CampaignRuleNotificationCampaignRuleConditions]',
            'campaign_rule_actions': 'list[CampaignRuleNotificationCampaignRuleActions]',
            'match_any_conditions': 'bool',
            'enabled': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'additional_properties': 'additionalProperties',
            'campaign_rule_entities': 'campaignRuleEntities',
            'campaign_rule_conditions': 'campaignRuleConditions',
            'campaign_rule_actions': 'campaignRuleActions',
            'match_any_conditions': 'matchAnyConditions',
            'enabled': 'enabled'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._additional_properties = None
        self._campaign_rule_entities = None
        self._campaign_rule_conditions = None
        self._campaign_rule_actions = None
        self._match_any_conditions = None
        self._enabled = None

    @property
    def id(self):
        """
        Gets the id of this CampaignRuleNotification.


        :return: The id of this CampaignRuleNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CampaignRuleNotification.


        :param id: The id of this CampaignRuleNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CampaignRuleNotification.


        :return: The name of this CampaignRuleNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CampaignRuleNotification.


        :param name: The name of this CampaignRuleNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this CampaignRuleNotification.


        :return: The date_created of this CampaignRuleNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CampaignRuleNotification.


        :param date_created: The date_created of this CampaignRuleNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CampaignRuleNotification.


        :return: The date_modified of this CampaignRuleNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CampaignRuleNotification.


        :param date_modified: The date_modified of this CampaignRuleNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this CampaignRuleNotification.


        :return: The version of this CampaignRuleNotification.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CampaignRuleNotification.


        :param version: The version of this CampaignRuleNotification.
        :type: int
        """
        
        self._version = version

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this CampaignRuleNotification.


        :return: The additional_properties of this CampaignRuleNotification.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this CampaignRuleNotification.


        :param additional_properties: The additional_properties of this CampaignRuleNotification.
        :type: object
        """
        
        self._additional_properties = additional_properties

    @property
    def campaign_rule_entities(self):
        """
        Gets the campaign_rule_entities of this CampaignRuleNotification.


        :return: The campaign_rule_entities of this CampaignRuleNotification.
        :rtype: CampaignRuleNotificationCampaignRuleEntities
        """
        return self._campaign_rule_entities

    @campaign_rule_entities.setter
    def campaign_rule_entities(self, campaign_rule_entities):
        """
        Sets the campaign_rule_entities of this CampaignRuleNotification.


        :param campaign_rule_entities: The campaign_rule_entities of this CampaignRuleNotification.
        :type: CampaignRuleNotificationCampaignRuleEntities
        """
        
        self._campaign_rule_entities = campaign_rule_entities

    @property
    def campaign_rule_conditions(self):
        """
        Gets the campaign_rule_conditions of this CampaignRuleNotification.


        :return: The campaign_rule_conditions of this CampaignRuleNotification.
        :rtype: list[CampaignRuleNotificationCampaignRuleConditions]
        """
        return self._campaign_rule_conditions

    @campaign_rule_conditions.setter
    def campaign_rule_conditions(self, campaign_rule_conditions):
        """
        Sets the campaign_rule_conditions of this CampaignRuleNotification.


        :param campaign_rule_conditions: The campaign_rule_conditions of this CampaignRuleNotification.
        :type: list[CampaignRuleNotificationCampaignRuleConditions]
        """
        
        self._campaign_rule_conditions = campaign_rule_conditions

    @property
    def campaign_rule_actions(self):
        """
        Gets the campaign_rule_actions of this CampaignRuleNotification.


        :return: The campaign_rule_actions of this CampaignRuleNotification.
        :rtype: list[CampaignRuleNotificationCampaignRuleActions]
        """
        return self._campaign_rule_actions

    @campaign_rule_actions.setter
    def campaign_rule_actions(self, campaign_rule_actions):
        """
        Sets the campaign_rule_actions of this CampaignRuleNotification.


        :param campaign_rule_actions: The campaign_rule_actions of this CampaignRuleNotification.
        :type: list[CampaignRuleNotificationCampaignRuleActions]
        """
        
        self._campaign_rule_actions = campaign_rule_actions

    @property
    def match_any_conditions(self):
        """
        Gets the match_any_conditions of this CampaignRuleNotification.


        :return: The match_any_conditions of this CampaignRuleNotification.
        :rtype: bool
        """
        return self._match_any_conditions

    @match_any_conditions.setter
    def match_any_conditions(self, match_any_conditions):
        """
        Sets the match_any_conditions of this CampaignRuleNotification.


        :param match_any_conditions: The match_any_conditions of this CampaignRuleNotification.
        :type: bool
        """
        
        self._match_any_conditions = match_any_conditions

    @property
    def enabled(self):
        """
        Gets the enabled of this CampaignRuleNotification.


        :return: The enabled of this CampaignRuleNotification.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this CampaignRuleNotification.


        :param enabled: The enabled of this CampaignRuleNotification.
        :type: bool
        """
        
        self._enabled = enabled

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class OutboundRouteBase(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OutboundRouteBase - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'classification_types': 'list[str]',
            'enabled': 'bool',
            'distribution': 'str',
            'external_trunk_bases': 'list[UriReference]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'classification_types': 'classificationTypes',
            'enabled': 'enabled',
            'distribution': 'distribution',
            'external_trunk_bases': 'externalTrunkBases',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._classification_types = None
        self._enabled = None
        self._distribution = None
        self._external_trunk_bases = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OutboundRouteBase.
        The globally unique identifier for the object.

        :return: The id of this OutboundRouteBase.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OutboundRouteBase.
        The globally unique identifier for the object.

        :param id: The id of this OutboundRouteBase.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OutboundRouteBase.
        The name of the entity.

        :return: The name of this OutboundRouteBase.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OutboundRouteBase.
        The name of the entity.

        :param name: The name of this OutboundRouteBase.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this OutboundRouteBase.


        :return: The description of this OutboundRouteBase.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OutboundRouteBase.


        :param description: The description of this OutboundRouteBase.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this OutboundRouteBase.


        :return: The version of this OutboundRouteBase.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this OutboundRouteBase.


        :param version: The version of this OutboundRouteBase.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this OutboundRouteBase.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this OutboundRouteBase.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this OutboundRouteBase.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this OutboundRouteBase.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this OutboundRouteBase.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this OutboundRouteBase.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this OutboundRouteBase.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this OutboundRouteBase.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this OutboundRouteBase.


        :return: The modified_by of this OutboundRouteBase.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this OutboundRouteBase.


        :param modified_by: The modified_by of this OutboundRouteBase.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this OutboundRouteBase.


        :return: The created_by of this OutboundRouteBase.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this OutboundRouteBase.


        :param created_by: The created_by of this OutboundRouteBase.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this OutboundRouteBase.


        :return: The state of this OutboundRouteBase.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this OutboundRouteBase.


        :param state: The state of this OutboundRouteBase.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for state -> " + state
            self._state = "outdated_sdk_version"
        else:
            self._state = state.lower()

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this OutboundRouteBase.


        :return: The modified_by_app of this OutboundRouteBase.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this OutboundRouteBase.


        :param modified_by_app: The modified_by_app of this OutboundRouteBase.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this OutboundRouteBase.


        :return: The created_by_app of this OutboundRouteBase.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this OutboundRouteBase.


        :param created_by_app: The created_by_app of this OutboundRouteBase.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def classification_types(self):
        """
        Gets the classification_types of this OutboundRouteBase.
        The site associated to the outbound route.

        :return: The classification_types of this OutboundRouteBase.
        :rtype: list[str]
        """
        return self._classification_types

    @classification_types.setter
    def classification_types(self, classification_types):
        """
        Sets the classification_types of this OutboundRouteBase.
        The site associated to the outbound route.

        :param classification_types: The classification_types of this OutboundRouteBase.
        :type: list[str]
        """
        
        self._classification_types = classification_types

    @property
    def enabled(self):
        """
        Gets the enabled of this OutboundRouteBase.


        :return: The enabled of this OutboundRouteBase.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this OutboundRouteBase.


        :param enabled: The enabled of this OutboundRouteBase.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def distribution(self):
        """
        Gets the distribution of this OutboundRouteBase.


        :return: The distribution of this OutboundRouteBase.
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """
        Sets the distribution of this OutboundRouteBase.


        :param distribution: The distribution of this OutboundRouteBase.
        :type: str
        """
        allowed_values = ["SEQUENTIAL", "RANDOM"]
        if distribution.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for distribution -> " + distribution
            self._distribution = "outdated_sdk_version"
        else:
            self._distribution = distribution.lower()

    @property
    def external_trunk_bases(self):
        """
        Gets the external_trunk_bases of this OutboundRouteBase.
        Trunk base settings of trunkType \"EXTERNAL\".  This base must also be set on an edge logical interface for correct routing.

        :return: The external_trunk_bases of this OutboundRouteBase.
        :rtype: list[UriReference]
        """
        return self._external_trunk_bases

    @external_trunk_bases.setter
    def external_trunk_bases(self, external_trunk_bases):
        """
        Sets the external_trunk_bases of this OutboundRouteBase.
        Trunk base settings of trunkType \"EXTERNAL\".  This base must also be set on an edge logical interface for correct routing.

        :param external_trunk_bases: The external_trunk_bases of this OutboundRouteBase.
        :type: list[UriReference]
        """
        
        self._external_trunk_bases = external_trunk_bases

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OutboundRouteBase.
        The URI for this object

        :return: The self_uri of this OutboundRouteBase.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OutboundRouteBase.
        The URI for this object

        :param self_uri: The self_uri of this OutboundRouteBase.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EdgeOfflineConfigurationInterface(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeOfflineConfigurationInterface - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'routes': 'list[DomainNetworkRoute]',
            'addresses': 'list[DomainNetworkAddress]',
            'ipv4_capabilities': 'DomainCapabilities',
            'ipv6_capabilities': 'DomainCapabilities'
        }

        self.attribute_map = {
            'routes': 'routes',
            'addresses': 'addresses',
            'ipv4_capabilities': 'ipv4Capabilities',
            'ipv6_capabilities': 'ipv6Capabilities'
        }

        self._routes = None
        self._addresses = None
        self._ipv4_capabilities = None
        self._ipv6_capabilities = None

    @property
    def routes(self):
        """
        Gets the routes of this EdgeOfflineConfigurationInterface.
        The list of routes assigned to this interface.

        :return: The routes of this EdgeOfflineConfigurationInterface.
        :rtype: list[DomainNetworkRoute]
        """
        return self._routes

    @routes.setter
    def routes(self, routes):
        """
        Sets the routes of this EdgeOfflineConfigurationInterface.
        The list of routes assigned to this interface.

        :param routes: The routes of this EdgeOfflineConfigurationInterface.
        :type: list[DomainNetworkRoute]
        """
        
        self._routes = routes

    @property
    def addresses(self):
        """
        Gets the addresses of this EdgeOfflineConfigurationInterface.
        The list of IP addresses on this interface.  Priority of dns addresses are based on order in the list.

        :return: The addresses of this EdgeOfflineConfigurationInterface.
        :rtype: list[DomainNetworkAddress]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this EdgeOfflineConfigurationInterface.
        The list of IP addresses on this interface.  Priority of dns addresses are based on order in the list.

        :param addresses: The addresses of this EdgeOfflineConfigurationInterface.
        :type: list[DomainNetworkAddress]
        """
        
        self._addresses = addresses

    @property
    def ipv4_capabilities(self):
        """
        Gets the ipv4_capabilities of this EdgeOfflineConfigurationInterface.
        IPv4 interface settings.

        :return: The ipv4_capabilities of this EdgeOfflineConfigurationInterface.
        :rtype: DomainCapabilities
        """
        return self._ipv4_capabilities

    @ipv4_capabilities.setter
    def ipv4_capabilities(self, ipv4_capabilities):
        """
        Sets the ipv4_capabilities of this EdgeOfflineConfigurationInterface.
        IPv4 interface settings.

        :param ipv4_capabilities: The ipv4_capabilities of this EdgeOfflineConfigurationInterface.
        :type: DomainCapabilities
        """
        
        self._ipv4_capabilities = ipv4_capabilities

    @property
    def ipv6_capabilities(self):
        """
        Gets the ipv6_capabilities of this EdgeOfflineConfigurationInterface.
        IPv6 interface settings.

        :return: The ipv6_capabilities of this EdgeOfflineConfigurationInterface.
        :rtype: DomainCapabilities
        """
        return self._ipv6_capabilities

    @ipv6_capabilities.setter
    def ipv6_capabilities(self, ipv6_capabilities):
        """
        Sets the ipv6_capabilities of this EdgeOfflineConfigurationInterface.
        IPv6 interface settings.

        :param ipv6_capabilities: The ipv6_capabilities of this EdgeOfflineConfigurationInterface.
        :type: DomainCapabilities
        """
        
        self._ipv6_capabilities = ipv6_capabilities

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DncListNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DncListNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'additional_properties': 'object',
            'import_status': 'ContactListNotificationImportStatus',
            'size': 'int',
            'dnc_source_type': 'str',
            'login_id': 'str',
            'dnc_codes': 'list[str]',
            'license_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'additional_properties': 'additionalProperties',
            'import_status': 'importStatus',
            'size': 'size',
            'dnc_source_type': 'dncSourceType',
            'login_id': 'loginId',
            'dnc_codes': 'dncCodes',
            'license_id': 'licenseId'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._additional_properties = None
        self._import_status = None
        self._size = None
        self._dnc_source_type = None
        self._login_id = None
        self._dnc_codes = None
        self._license_id = None

    @property
    def id(self):
        """
        Gets the id of this DncListNotification.


        :return: The id of this DncListNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DncListNotification.


        :param id: The id of this DncListNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DncListNotification.


        :return: The name of this DncListNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DncListNotification.


        :param name: The name of this DncListNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DncListNotification.


        :return: The date_created of this DncListNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DncListNotification.


        :param date_created: The date_created of this DncListNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DncListNotification.


        :return: The date_modified of this DncListNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DncListNotification.


        :param date_modified: The date_modified of this DncListNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DncListNotification.


        :return: The version of this DncListNotification.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DncListNotification.


        :param version: The version of this DncListNotification.
        :type: int
        """
        
        self._version = version

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DncListNotification.


        :return: The additional_properties of this DncListNotification.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DncListNotification.


        :param additional_properties: The additional_properties of this DncListNotification.
        :type: object
        """
        
        self._additional_properties = additional_properties

    @property
    def import_status(self):
        """
        Gets the import_status of this DncListNotification.


        :return: The import_status of this DncListNotification.
        :rtype: ContactListNotificationImportStatus
        """
        return self._import_status

    @import_status.setter
    def import_status(self, import_status):
        """
        Sets the import_status of this DncListNotification.


        :param import_status: The import_status of this DncListNotification.
        :type: ContactListNotificationImportStatus
        """
        
        self._import_status = import_status

    @property
    def size(self):
        """
        Gets the size of this DncListNotification.


        :return: The size of this DncListNotification.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this DncListNotification.


        :param size: The size of this DncListNotification.
        :type: int
        """
        
        self._size = size

    @property
    def dnc_source_type(self):
        """
        Gets the dnc_source_type of this DncListNotification.


        :return: The dnc_source_type of this DncListNotification.
        :rtype: str
        """
        return self._dnc_source_type

    @dnc_source_type.setter
    def dnc_source_type(self, dnc_source_type):
        """
        Sets the dnc_source_type of this DncListNotification.


        :param dnc_source_type: The dnc_source_type of this DncListNotification.
        :type: str
        """
        allowed_values = ["RDS", "DNC_COM", "GRYPHON"]
        if dnc_source_type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for dnc_source_type -> " + dnc_source_type
            self._dnc_source_type = "outdated_sdk_version"
        else:
            self._dnc_source_type = dnc_source_type.lower()

    @property
    def login_id(self):
        """
        Gets the login_id of this DncListNotification.


        :return: The login_id of this DncListNotification.
        :rtype: str
        """
        return self._login_id

    @login_id.setter
    def login_id(self, login_id):
        """
        Sets the login_id of this DncListNotification.


        :param login_id: The login_id of this DncListNotification.
        :type: str
        """
        
        self._login_id = login_id

    @property
    def dnc_codes(self):
        """
        Gets the dnc_codes of this DncListNotification.


        :return: The dnc_codes of this DncListNotification.
        :rtype: list[str]
        """
        return self._dnc_codes

    @dnc_codes.setter
    def dnc_codes(self, dnc_codes):
        """
        Sets the dnc_codes of this DncListNotification.


        :param dnc_codes: The dnc_codes of this DncListNotification.
        :type: list[str]
        """
        
        self._dnc_codes = dnc_codes

    @property
    def license_id(self):
        """
        Gets the license_id of this DncListNotification.


        :return: The license_id of this DncListNotification.
        :rtype: str
        """
        return self._license_id

    @license_id.setter
    def license_id(self, license_id):
        """
        Sets the license_id of this DncListNotification.


        :param license_id: The license_id of this DncListNotification.
        :type: str
        """
        
        self._license_id = license_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AggregationResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AggregationResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'dimension': 'str',
            'metric': 'str',
            'count': 'int',
            'results': 'list[AggregationResultEntry]'
        }

        self.attribute_map = {
            'type': 'type',
            'dimension': 'dimension',
            'metric': 'metric',
            'count': 'count',
            'results': 'results'
        }

        self._type = None
        self._dimension = None
        self._metric = None
        self._count = None
        self._results = None

    @property
    def type(self):
        """
        Gets the type of this AggregationResult.


        :return: The type of this AggregationResult.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AggregationResult.


        :param type: The type of this AggregationResult.
        :type: str
        """
        allowed_values = ["termFrequency", "numericRange"]
        if type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for type -> " + type
            self._type = "outdated_sdk_version"
        else:
            self._type = type.lower()

    @property
    def dimension(self):
        """
        Gets the dimension of this AggregationResult.
        For termFrequency aggregations

        :return: The dimension of this AggregationResult.
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """
        Sets the dimension of this AggregationResult.
        For termFrequency aggregations

        :param dimension: The dimension of this AggregationResult.
        :type: str
        """
        
        self._dimension = dimension

    @property
    def metric(self):
        """
        Gets the metric of this AggregationResult.
        For numericRange aggregations

        :return: The metric of this AggregationResult.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this AggregationResult.
        For numericRange aggregations

        :param metric: The metric of this AggregationResult.
        :type: str
        """
        
        self._metric = metric

    @property
    def count(self):
        """
        Gets the count of this AggregationResult.


        :return: The count of this AggregationResult.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this AggregationResult.


        :param count: The count of this AggregationResult.
        :type: int
        """
        
        self._count = count

    @property
    def results(self):
        """
        Gets the results of this AggregationResult.


        :return: The results of this AggregationResult.
        :rtype: list[AggregationResultEntry]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this AggregationResult.


        :param results: The results of this AggregationResult.
        :type: list[AggregationResultEntry]
        """
        
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

